@@ -11,6 +11,10 @@ from amuse.units import units
 from amuse import datamodel
 from amuse.ic import plummer
 from amuse.ic.plummer import new_plummer_model
+
+from amuse.test.suite.codes_tests.gd_tests import (
+    _TestGravitationalDynamicsInterface,
+)
 try:
     from matplotlib import pyplot
     HAS_MATPLOTLIB = True
@@ -18,136 +22,58 @@ except ImportError:
     HAS_MATPLOTLIB = False
 
 
-class TestHermiteInterface(TestWithMPI):
+class TestHermiteInterface(_TestGravitationalDynamicsInterface, TestWithMPI):
+    def gravity_code_interface(self):
+        return HermiteInterface
 
-    def test0(self):
-        instance = HermiteInterface()
-        self.assertTrue("Hut" in instance.all_literature_references_string())
-        instance.cleanup_code()
-        instance.stop()
-    
-    def test1(self):
-        instance = HermiteInterface()
-        instance.initialize_code()
-    
-        res1 = instance.new_particle(mass = 11.0, radius = 2.0, x = 0.0, y = 0.0, z = 0.0, vx = 0.0, vy = 0.0, vz = 0.0)
-        res2 = instance.new_particle(mass = 21.0, radius = 5.0, x = 10.0, y = 0.0, z = 0.0, vx = 10.0, vy = 0.0, vz = 0.0)
-        
-        self.assertEqual(0, res1['index_of_the_particle'])
-        self.assertEqual(1, res2['index_of_the_particle'])
-    
-        retrieved_state1 = instance.get_state(0)
-        retrieved_state2 = instance.get_state(1)
-    
-        self.assertEqual(11.0,  retrieved_state1['mass'])
-        self.assertEqual(21.0,  retrieved_state2['mass'])
-        self.assertEqual(0.0,  retrieved_state1['x'])
-        self.assertEqual(10.0,  retrieved_state2['x'])
-        self.assertEqual(2.0,  retrieved_state1['radius'])
-        self.assertEqual(5.0,  retrieved_state2['radius'])
-    
-        instance.cleanup_code()
-        instance.stop()
-
-    def test2(self):
-        instance = HermiteInterface()
-        instance.initialize_code()
-
-        for i in [0, 1, 2]:
-            temp_particle = instance.new_particle(mass = i, radius = 1.0, x = 0.0, y = 0.0, z = 0.0, vx = 0.0, vy = 0.0, vz = 0.0)
-            self.assertEqual(i, temp_particle['index_of_the_particle'])
-            
-        instance.delete_particle(1)
-      
-        self.assertEqual(2, instance.get_number_of_particles()['number_of_particles'])
-        
-        self.assertEqual(0, instance.get_index_of_first_particle()['index_of_the_particle'])
-        
-        self.assertEqual(2, instance.get_index_of_next_particle(0)['index_of_the_next_particle'])
-        self.assertEqual(0, instance.get_index_of_next_particle(0)['__result'])
-        self.assertEqual(-1, instance.get_index_of_next_particle(1)['__result'])
-        self.assertEqual(1, instance.get_index_of_next_particle(2)['__result'])
-        instance.cleanup_code()
-        instance.stop()
-        
-    def test3(self):
-        hermite = HermiteInterface()
-        self.assertEqual(0, hermite.set_eps2(0.101))
-        self.assertEqual([0.101, 0], list(hermite.get_eps2().values()))
-        self.assertEqual(0, hermite.set_eps2(0.2))
-        self.assertEqual([0.2, 0], list(hermite.get_eps2().values()))
-        hermite.cleanup_code()
-        hermite.stop()
-
-    def test4(self):
-        hermite = HermiteInterface()
-        self.assertEqual([0, 0], list(hermite.get_is_time_reversed_allowed().values()))
-        self.assertEqual(0, hermite.set_is_time_reversed_allowed(1))
-        self.assertEqual([1, 0], list(hermite.get_is_time_reversed_allowed().values()))
-        hermite.cleanup_code()
-        hermite.stop()
-
-    def test5(self):
-        hermite = HermiteInterface()
-        hermite.initialize_code()
-        
-        hermite.new_particle([10,20],[0,0],[0,0], [0,0], [0,0], [0,0], [0,0],[1,1])
-        retrieved_state = hermite.get_state(0)
-        
-        self.assertEqual(10.0,  retrieved_state['mass'])
-        self.assertEqual(1, retrieved_state['radius'])
-    
-        retrieved_state = hermite.get_state([0,1])
-        self.assertEqual(20.0,  retrieved_state['mass'][1])
-        self.assertEqual(hermite.get_number_of_particles()['number_of_particles'], 2)
-        hermite.cleanup_code() 
-        hermite.stop()
+    def reference_includes(self):
+        return "Hut"
 
     def test6(self):
         hermite = HermiteInterface()
         hermite.initialize_code()
-        
+
         hermite.new_particle([10,10],[-1,1],[0,0], [0,0], [0,0], [0,0], [0,0], [1,1])
         retrieved_state = hermite.get_state(0)
-        
+
         retr = hermite.get_potential_at_point(0.01, 0,0,0)
         self.assertEqual(retr['phi'], -20.0)
         hermite.cleanup_code()
         hermite.stop()
-       
+
     def test7(self):
         instance = HermiteInterface()
         instance.initialize_code()
         instance.set_eps2(0.1 * 0.1)
         instance.commit_parameters()
-        id1,errorcode = instance.new_particle(mass = 10.0, radius = 1.0, x = 0.0, y = 0.0, z = 0.0, vx = 0.0, vy = 0.0, vz = 0.0)
-        id2,errorcode = instance.new_particle(mass = 10.0, radius = 1.0, x = 2.0, y = 0.0, z = 0.0, vx = 10.0, vy = 0.0, vz = 0.0)
-        
+        id1,errorcode = instance.new_particle(mass=10.0, radius=1.0, x=0.0, y=0.0, z=0.0, vx=0.0, vy=0.0, vz=0.0)
+        id2,errorcode = instance.new_particle(mass=10.0, radius=1.0, x=2.0, y=0.0, z=0.0, vx=10.0, vy=0.0, vz=0.0)
+
         instance.commit_particles()
         potential, errorcode = instance.get_potential(id1)
         self.assertEqual(errorcode, 0)
         self.assertAlmostRelativeEquals(potential,  -10.0 / numpy.sqrt(2.0**2 + 0.1**2), 8)
-        
+
         potential, errorcode = instance.get_potential(id2)
         self.assertEqual(errorcode, 0)
         self.assertAlmostRelativeEquals(potential,  -10.0 / numpy.sqrt(2.0**2 + 0.1**2), 8)
-        
+
         total_potential, errorcode = instance.get_potential_energy()
         potentials, errorcode = instance.get_potential([id1, id2])
         instance.cleanup_code()
         instance.stop()
-        
+
         self.assertAlmostRelativeEquals(total_potential, numpy.sum(potentials * [10.0, 10.0]) / 2.0)
-        
+
 
     def test8(self):
         instance = HermiteInterface()
         instance.initialize_code()
         instance.set_eps2(0)
         instance.commit_parameters()
-        id1,errorcode = instance.new_particle(mass = 10.0, radius = 1.0, x = 0.0, y = 0.0, z = 0.0, vx = 0.0, vy = 0.0, vz = 0.0)
-        id2,errorcode = instance.new_particle(mass = 1.0, radius = 1.0, x = 2.0, y = 0.0, z = 0.0, vx = 10.0, vy = 0.0, vz = 0.0)
-        
+        id1,errorcode = instance.new_particle(mass=10.0, radius=1.0, x=0.0, y=0.0, z=0.0, vx=0.0, vy=0.0, vz=0.0)
+        id2,errorcode = instance.new_particle(mass=1.0, radius=1.0, x=2.0, y=0.0, z=0.0, vx=10.0, vy=0.0, vz=0.0)
+
         instance.commit_particles()
         potential, errorcode = instance.get_potential(id1)
         self.assertEqual(errorcode, 0)
@@ -156,10 +82,10 @@ class TestHermiteInterface(TestWithMPI):
         potentials, errorcode = instance.get_potential([id1, id2])
         instance.cleanup_code()
         instance.stop()
-        
+
         self.assertAlmostRelativeEquals(total_potential, numpy.sum(potentials * [10.0, 1.0]) / 2.0)
-        
-    
+
+
     def test9(self):
         print("Test HermiteInterface evolve_model")
         instance = HermiteInterface()
@@ -167,24 +93,24 @@ class TestHermiteInterface(TestWithMPI):
         self.assertEqual(0, instance.set_dt_param(0.001))
         self.assertEqual(0, instance.set_end_time_accuracy_factor(0.0))
         self.assertEqual(0, instance.commit_parameters())
-        
+
         # Set up an equal-mass binary on a circular orbit:
         self.assertEqual([0, 0], list(instance.new_particle(0.5,  0.5, 0, 0,  0, 0.5, 0, 0.01).values()))
         self.assertEqual([1, 0], list(instance.new_particle(0.5,  -0.5, 0, 0,  0,-0.5, 0, 0.01).values()))
         self.assertEqual(0, instance.commit_particles())
-        
+
         self.assertEqual(0, instance.evolve_model(math.pi))
         for result, expected in zip(list(instance.get_position(0).values()), [-0.5, 0.0, 0.0, 0]):
             self.assertAlmostEqual(result, expected, 3)
         for result, expected in zip(list(instance.get_position(1).values()), [0.5, 0.0, 0.0, 0]):
             self.assertAlmostEqual(result, expected, 3)
-        
+
         self.assertEqual(0, instance.evolve_model(2 * math.pi))
         for result, expected in zip(list(instance.get_position(0).values()), [0.5, 0.0, 0.0, 0]):
             self.assertAlmostEqual(result, expected, 3)
         for result, expected in zip(list(instance.get_position(1).values()), [-0.5, 0.0, 0.0, 0]):
             self.assertAlmostEqual(result, expected, 3)
-        
+
         self.assertEqual(0, instance.cleanup_code())
         instance.cleanup_code()
         instance.stop()
@@ -204,86 +130,86 @@ class TestHermite(TestWithMPI):
         earth.radius = units.km(6371) 
         earth.position = units.km(numpy.array((149.5e6,0.0,0.0)))
         earth.velocity = units.ms(numpy.array((0.0,29800,0.0)))
-        
+
         return stars
-        
-    
+
+
     def test1(self):
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 149.5e6 | units.km)
-    
+
         hermite = Hermite(convert_nbody)
         hermite.initialize_code()
         hermite.parameters.epsilon_squared = 0.0 | units.AU**2
         hermite.parameters.end_time_accuracy_factor = 0.0
         hermite.dt_dia = 5000
-        
+
         stars = self.new_system_of_sun_and_earth()
         earth = stars[1]
-                
+
         hermite.particles.add_particles(stars)
-        
+
         hermite.evolve_model(365.0 | units.day)
         hermite.particles.copy_values_of_all_attributes_to(stars)
-        
+
         position_at_start = earth.position.value_in(units.AU)[0]
         position_after_full_rotation = earth.position.value_in(units.AU)[0]
         self.assertAlmostRelativeEqual(position_at_start, position_after_full_rotation, 6)
-        
+
         hermite.evolve_model(365.0 + (365.0 / 2) | units.day)
-        
+
         hermite.particles.copy_values_of_all_attributes_to(stars)
         position_after_half_a_rotation = earth.position.value_in(units.AU)[0]
         self.assertAlmostRelativeEqual(-position_at_start, position_after_half_a_rotation, 3)
-                
+
         hermite.evolve_model(365.0 + (365.0 / 2) + (365.0 / 4)  | units.day)
-        
+
         hermite.particles.copy_values_of_all_attributes_to(stars)
         position_after_half_a_rotation = earth.position.value_in(units.AU)[1]
         self.assertAlmostRelativeEqual(-position_at_start, position_after_half_a_rotation, 3)
-        
+
         hermite.cleanup_code()
         hermite.stop()
-        
+
 
     def test2(self):
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 149.5e6 | units.km)
-    
+
         instance = Hermite(convert_nbody)
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.0 | units.AU**2
         instance.dt_dia = 5000
-        
+
         stars = self.new_system_of_sun_and_earth()
         earth = stars[1]
         instance.particles.add_particles(stars)
-        
+
         for x in range(1, 500, 10):
             instance.evolve_model(x | units.day)
             instance.particles.copy_values_of_all_attributes_to(stars)
             stars.savepoint()
-        
+
         if HAS_MATPLOTLIB:
             figure = pyplot.figure()
             plot = figure.add_subplot(1,1,1)
-            
+
             x_points = earth.get_timeline_of_attribute("x")
             y_points = earth.get_timeline_of_attribute("y")
-            
+
             x_points_in_AU = [t_x[1].value_in(units.AU) for t_x in x_points]
             y_points_in_AU = [t_x1[1].value_in(units.AU) for t_x1 in y_points]
-            
-            plot.scatter(x_points_in_AU,y_points_in_AU, color = "b", marker = 'o')
-            
+
+            plot.scatter(x_points_in_AU,y_points_in_AU, color="b", marker='o')
+
             plot.set_xlim(-1.5, 1.5)
             plot.set_ylim(-1.5, 1.5)
-               
-            
+
+
             test_results_path = self.get_path_to_results()
             output_file = os.path.join(test_results_path, "hermite-earth-sun2.svg")
             figure.savefig(output_file)
-        
-        
-        
+
+
+
         instance.cleanup_code()
         instance.stop()
 
@@ -294,7 +220,7 @@ class TestHermite(TestWithMPI):
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.00001 | units.AU**2
         instance.dt_dia = 5000
-        
+
         stars = datamodel.Stars(2)
         star1 = stars[0]
         star2 = stars[1]
@@ -308,42 +234,42 @@ class TestHermite(TestWithMPI):
         star2.position = units.AU(numpy.array((1.0,0.0,0.0)))
         star2.velocity = units.AUd(numpy.array((0.0,0.0,0.0)))
         star2.radius = units.RSun(100.0)
-        
+
         instance.particles.add_particles(stars)
-    
+
         for x in range(1,2000,10):
             instance.evolve_model(x | units.day)
             instance.particles.copy_values_of_all_attributes_to(stars)
             stars.savepoint()
-        
-        
+
+
         instance.cleanup_code()
         instance.stop()
-    
+
     def test4(self):
         convert_nbody = nbody_system.nbody_to_si(5.0 | units.kg, 10.0 | units.m)
 
         instance = Hermite(convert_nbody)
         instance.initialize_code()
-        
+
         particles = datamodel.Particles(2)
         self.assertEqual(len(instance.particles), 0)
-        
+
         particles.mass = [15.0, 30.0] | units.kg
         particles.radius =  [10.0, 20.0] | units.m
         particles.position = [[10.0, 20.0, 30.0], [20.0, 40.0, 60.0]] | units.m
         particles.velocity = [[0.0, 0.0, 0.0], [0.0, 0.0, 0.0]] | units.m / units.s
 
-        
+
         instance.particles.add_particles(particles)
         self.assertEqual(len(instance.particles), 2)
-        
+
         instance.particles.mass =  [17.0, 33.0] | units.kg
-        
-        
+
+
         self.assertEqual(instance.get_mass(0), 17.0| units.kg) 
         self.assertEqual(instance.get_mass(1), 33.0| units.kg)  
-        
+
         instance.stop()
 
     def test5(self):
@@ -351,23 +277,23 @@ class TestHermite(TestWithMPI):
 
         instance = Hermite(convert_nbody)
         instance.initialize_code()
-        
+
         particles = datamodel.Particles(2)
         self.assertEqual(len(instance.particles), 0)
-        
+
         particles.mass = [15.0, 30.0] | units.kg
         particles.radius =  [10.0, 20.0] | units.m
         particles.position = [[10.0, 20.0, 30.0], [20.0, 40.0, 60.0]] | units.m
         particles.velocity = [[0.0, 0.0, 0.0], [0.0, 0.0, 0.0]] | units.m / units.s
 
-        
+
         instance.particles.add_particles(particles)
         self.assertEqual(len(instance.particles), 2)
         instance.set_state(1, 16|units.kg, 
                            20.0|units.m, 40.0|units.m, 60.0|units.m, 
                            1.0|units.ms, 1.0|units.ms, 1.0|units.ms , 
                            20.0|units.m)
-        
+
         curr_state =  instance.get_state(1)
         for expected, actual in zip([16|units.kg, 
                            20.0|units.m, 40.0|units.m, 60.0|units.m, 
@@ -375,35 +301,35 @@ class TestHermite(TestWithMPI):
                            20.0|units.m], curr_state):
             self.assertAlmostRelativeEquals(expected, actual)
         instance.stop()
-        
+
         self.assertEqual(curr_state[0], 16|units.kg, 8)
-    
+
     def test6(self):
         print("Test6: Testing Hermite parameters")
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.yr, 1.0 | units.AU)
         instance = Hermite(convert_nbody)
-        
+
         value = instance.get_eps2()
         self.assertEqual(0.0 | units.AU**2 , value)
         self.assertAlmostEqual(0.0 | units.AU**2, instance.parameters.epsilon_squared, in_units=units.AU**2)
         for x in [0.01, 0.1, 0.2]:
             instance.parameters.epsilon_squared = x | units.AU**2
             self.assertAlmostEqual(x | units.AU**2, instance.parameters.epsilon_squared, in_units=units.AU**2)
-        
+
         value = instance.get_dt_param()
         self.assertEqual(0.03 , value)
         self.assertAlmostEqual(0.03 , instance.parameters.dt_param)
         for x in [0.001, 0.01, 0.1]:
             instance.parameters.dt_param = x
             self.assertAlmostEqual(x, instance.parameters.dt_param)
-        
+
         value = instance.get_dt_dia()
         self.assertAlmostEqual(1.0 | units.yr, value)
         self.assertAlmostEqual(1.0 | units.yr, instance.parameters.dt_dia, in_units=units.yr)
         for x in [0.1, 10.0, 100.0]:
             instance.parameters.dt_dia = x | units.yr
             self.assertAlmostEqual(x | units.yr, instance.parameters.dt_dia, in_units=units.yr)
-        
+
         value = instance.get_begin_time()
         self.assertEqual(0.0| units.yr, value)
         self.assertAlmostEqual(0.0 | units.yr, instance.parameters.begin_time, in_units=units.yr)
@@ -411,11 +337,11 @@ class TestHermite(TestWithMPI):
             instance.parameters.begin_time = x | units.yr
             self.assertAlmostEqual(x | units.yr, instance.parameters.begin_time, in_units=units.yr)
         instance.stop()
-    
+
     def test7(self):
         print("Test7: Testing effect of Hermite parameter epsilon_squared")
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 1.0 | units.AU)
-        
+
         particles = datamodel.Particles(2)
         sun = particles[0]
         sun.mass = 1.0 | units.MSun
@@ -428,7 +354,7 @@ class TestHermite(TestWithMPI):
         earth.radius = 6371.0 | units.km
         earth.position = [0.0, 1.0, 0.0] | units.AU
         earth.velocity = [2.0*numpy.pi, -0.0001, 0.0] | units.AU / units.yr
-        
+
         initial_direction = math.atan((earth.velocity[0]/earth.velocity[1]))
         final_direction = []
         for log_eps2 in range(-9,10,2):
@@ -448,7 +374,7 @@ class TestHermite(TestWithMPI):
         # Outcome is most sensitive to epsilon_squared when epsilon_squared = d(earth, sun)^2
         delta = [abs(final_direction[i+1]-final_direction[i]) for i in range(len(final_direction)-1)]
         self.assertEqual(delta[len(final_direction)//2 -1], max(delta))
-        
+
     def test8(self):
         print("Testing Hermite collision_detection")
         particles = datamodel.Particles(7)
@@ -458,7 +384,7 @@ class TestHermite(TestWithMPI):
         particles.y = 0 | nbody_system.length
         particles.z = 0 | nbody_system.length
         particles.velocity = [[2, 0, 0], [-2, 0, 0]]*3 + [[-4, 0, 0]] | nbody_system.speed
-        
+
         instance = Hermite()
         instance.initialize_code()
         instance.parameters.set_defaults()
@@ -466,7 +392,7 @@ class TestHermite(TestWithMPI):
         collisions = instance.stopping_conditions.collision_detection
         collisions.enable()
         instance.evolve_model(1.0 | nbody_system.time)
-        
+
         self.assertTrue(collisions.is_set())
         self.assertTrue(instance.model_time < 0.5 | nbody_system.time)
         self.assertEqual(len(collisions.particles(0)), 3)
@@ -475,19 +401,19 @@ class TestHermite(TestWithMPI):
         self.assertEqual(abs(collisions.particles(0).x - collisions.particles(1).x) <= 
                 (collisions.particles(0).radius + collisions.particles(1).radius),
                 [True, True, True])
-        
+
         sticky_merged = datamodel.Particles(len(collisions.particles(0)))
         sticky_merged.mass = collisions.particles(0).mass + collisions.particles(1).mass
         sticky_merged.radius = collisions.particles(0).radius
         for p1, p2, merged in zip(collisions.particles(0), collisions.particles(1), sticky_merged):
             merged.position = (p1 + p2).center_of_mass()
             merged.velocity = (p1 + p2).center_of_mass_velocity()
-        
+
         print(instance.model_time)
         print(instance.particles)
         instance.particles.remove_particles(collisions.particles(0) + collisions.particles(1))
         instance.particles.add_particles(sticky_merged)
-        
+
         instance.evolve_model(1.0 | nbody_system.time)
         print()
         print(instance.model_time)
@@ -501,28 +427,28 @@ class TestHermite(TestWithMPI):
                 (collisions.particles(0).radius + collisions.particles(1).radius),
                 [True])
         instance.stop()
-    
-        
+
+
     def test10(self):
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 149.5e6 | units.km)
-    
+
         instance = Hermite(convert_nbody)
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.0 | units.AU**2
         instance.parameters.stopping_conditions_number_of_steps = 10
         self.assertEqual(instance.parameters.stopping_conditions_number_of_steps,10)
-    
+
         stars = self.new_system_of_sun_and_earth()
         earth = stars[1]
-                
+
         instance.particles.add_particles(stars)
         instance.stopping_conditions.number_of_steps_detection.enable()
         instance.evolve_model(365.0 | units.day)
         self.assertTrue(instance.stopping_conditions.number_of_steps_detection.is_set())
         instance.particles.copy_values_of_all_attributes_to(stars)
-        
+
         instance.cleanup_code()
-        
+
         instance.stop()
 
     def test11(self):
@@ -535,7 +461,7 @@ class TestHermite(TestWithMPI):
         particles.vy =  0 | nbody_system.speed
         particles.vz =  0 | nbody_system.speed
         particles.mass = 1.0 | nbody_system.mass
-       
+
         instance = Hermite()
         instance.initialize_code()
         instance.parameters.stopping_conditions_number_of_steps = 2
@@ -545,7 +471,7 @@ class TestHermite(TestWithMPI):
         instance.evolve_model(10 | nbody_system.time)
         self.assertTrue(instance.stopping_conditions.number_of_steps_detection.is_set())
         self.assertTrue(instance.model_time < 10 | nbody_system.time)
-        
+
         instance.stop()
 
     def test12(self):
@@ -558,7 +484,7 @@ class TestHermite(TestWithMPI):
         particles.vy =  [0.0,0.0] | nbody_system.speed
         particles.vz =  [0.0,0.0]| nbody_system.speed
         particles.mass = [0.1,0.1] | nbody_system.mass
-       
+
         instance = Hermite()
         instance.initialize_code()
         instance.parameters.stopping_conditions_out_of_box_size = .5 | nbody_system.length
@@ -572,12 +498,12 @@ class TestHermite(TestWithMPI):
 
     def test13(self):
         particles = plummer.new_plummer_model(31)
-       
+
         instance = Hermite(number_of_workers=1)#, debugger="xterm")
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.01 | nbody_system.length ** 2
         instance.particles.add_particles(particles)
-        
+
         instance.evolve_model(0.1 | nbody_system.time)
         instance.synchronize_model()
         expected_positions = instance.particles.position
@@ -588,28 +514,28 @@ class TestHermite(TestWithMPI):
             instance.initialize_code()
             instance.parameters.epsilon_squared = 0.01 | nbody_system.length ** 2
             instance.particles.add_particles(particles)
-            
+
             instance.evolve_model(0.1 | nbody_system.time)
             instance.synchronize_model()
             positions_per_workers.append(instance.particles.position)
             instance.stop()
-         
-         
+
+
         for index, n in enumerate([2,3,4,5]):
             self.assertAlmostEqual(expected_positions, positions_per_workers[index], 15)
-    
+
     def test14(self):
         instance = Hermite()
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.00001 | nbody_system.length**2
-        
+
         particles = datamodel.Particles(2)
         particles.mass = [1.0, 1.0] | nbody_system.mass
         particles.radius =  [0.0001, 0.0001] | nbody_system.length
         particles.position = [[0.0,0.0,0.0], [2.0,0.0,0.0]] | nbody_system.length
         particles.velocity = [[0.0, 0.0, 0.0], [0.0, 0.0, 0.0]] | nbody_system.speed
         instance.particles.add_particles(particles)
-        
+
         zero = 0.0 | nbody_system.length
         fx, fy, fz = instance.get_gravity_at_point(zero, 1.0 | nbody_system.length, zero, zero)
         self.assertAlmostEqual(fx, 0.0 | nbody_system.acceleration, 6)
@@ -623,18 +549,18 @@ class TestHermite(TestWithMPI):
             potential1 = instance.get_potential_at_point(zero, x1, zero, zero)
             fx0, fy0, fz0 = instance.get_gravity_at_point(zero, x0, zero, zero)
             fx1, fy1, fz1 = instance.get_gravity_at_point(zero, x1, zero, zero)
-            
+
             self.assertAlmostEqual(fy0, 0.0 | nbody_system.acceleration, 6)
             self.assertAlmostEqual(fz0, 0.0 | nbody_system.acceleration, 6)
             self.assertAlmostEqual(fy1, 0.0 | nbody_system.acceleration, 6)
             self.assertAlmostEqual(fz1, 0.0 | nbody_system.acceleration, 6)
-            
+
             self.assertAlmostEqual(fx0, -1.0 * fx1, 5)
             fx = (-1.0 / (x0**2) + 1.0 / (x1**2)) * (1.0 | nbody_system.length ** 3 / nbody_system.time ** 2)
             self.assertAlmostEqual(fx, fx0, 2)
             self.assertAlmostEqual(potential0, potential1, 5)
         instance.stop()
-    
+
     def test15(self):
         particles = datamodel.Particles(2)
         particles.x = [0.0,10.0] | nbody_system.length
@@ -650,23 +576,23 @@ class TestHermite(TestWithMPI):
         instance.commit_particles()
         self.assertEqual(instance.particles[0].radius, 0.0 | nbody_system.length)
         p = datamodel.Particle(
-            x = 1.0  | nbody_system.length,
-            y = 2.0 | nbody_system.length,
-            z = 3.0 | nbody_system.length,
-            vx = 1.0  | nbody_system.speed,
-            vy = 2.0 | nbody_system.speed,
-            vz = 3.0 | nbody_system.speed,
-            mass = 1.0 | nbody_system.mass,
-            radius = 4.0 | nbody_system.length,
+            x=1.0  | nbody_system.length,
+            y=2.0 | nbody_system.length,
+            z=3.0 | nbody_system.length,
+            vx=1.0  | nbody_system.speed,
+            vy=2.0 | nbody_system.speed,
+            vz=3.0 | nbody_system.speed,
+            mass=1.0 | nbody_system.mass,
+            radius=4.0 | nbody_system.length,
         )
         instance.particles.add_particle(p) 
         self.assertEqual(instance.particles[0].radius, 0.0 | nbody_system.length)
         self.assertEqual(instance.particles[1].radius, 0.0 | nbody_system.length)
         self.assertEqual(instance.particles[2].radius, 4.0 | nbody_system.length)
-        
+
         instance.stop()
-        
-    
+
+
     def test16(self):
         particles = new_plummer_model(200)
         particles.scale_to_standard()
@@ -674,24 +600,24 @@ class TestHermite(TestWithMPI):
         instance.initialize_code()
         instance.parameters.epsilon_squared = 0.00000 | nbody_system.length**2
         instance.particles.add_particles(particles)
-        
+
         x = numpy.arange(-1,1,0.1) | nbody_system.length
         zero = numpy.zeros(len(x)) | nbody_system.length
         potential0 =  instance.get_potential_at_point(zero, x , zero, zero)
         instance.stop()
         for n in (2, 3, 4):
-            
-            instance = Hermite(number_of_workers = n)
+
+            instance = Hermite(number_of_workers=n)
             instance.initialize_code()
             instance.parameters.epsilon_squared = 0.00000 | nbody_system.length**2
             instance.particles.add_particles(particles)
             potential =  instance.get_potential_at_point(zero, x , zero, zero)
-        
+
             self.assertAlmostRelativeEquals(potential0, potential, 8)
             instance.stop()
-    
 
-    
+
+
     def test17(self):
         particles = new_plummer_model(50)
         particles.scale_to_standard()
@@ -699,16 +625,16 @@ class TestHermite(TestWithMPI):
         instance.parameters.epsilon_squared = 0.22000 | nbody_system.length**2
         instance.particles.add_particles(particles)
         self.assertEqual(len(instance.particles), 50)
-        
+
         instance.reset()
-        
+
         self.assertAlmostRelativeEquals(instance.parameters.epsilon_squared , 0.22000 | nbody_system.length**2)
         self.assertEqual(len(instance.particles), 0)
         instance.particles.add_particles(particles)
         self.assertEqual(len(instance.particles), 50)
         instance.stop()
-    
-        
+
+
     def test18(self):
         particles = datamodel.Particles(2)
         particles.x = [0.0,1.0] | nbody_system.length
@@ -738,10 +664,10 @@ class TestHermite(TestWithMPI):
         instance.parameters.end_time_accuracy_factor = +0.5
         instance.evolve_model(0.6 | nbody_system.time)
         self.assertAlmostRelativeEquals(instance.model_time, 0.6042733579 |nbody_system.time, 6)
-        
+
         instance.stop()
 
-    
+
     def test19(self):
         particles = datamodel.Particles(2)
         particles.x = [0.0,200.0] | nbody_system.length
@@ -759,65 +685,65 @@ class TestHermite(TestWithMPI):
         instance.parameters.end_time_accuracy_factor = 0.0
         instance.evolve_model(0.1 | nbody_system.time)
         self.assertAlmostRelativeEquals(instance.model_time, 0.1 |nbody_system.time, 5)
-       
+
         instance.stop()
-        
+
     def test20(self):
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 149.5e6 | units.km)
-    
+
         hermite = Hermite(convert_nbody)
         hermite.initialize_code()
         hermite.parameters.epsilon_squared = 0.0 | units.AU**2
         hermite.parameters.end_time_accuracy_factor = 0.0
         hermite.parameters.is_time_reversed_allowed = True
-        
+
         stars = self.new_system_of_sun_and_earth()
         earth = stars[1]
-                
+
         hermite.particles.add_particles(stars)
-        
+
         hermite.evolve_model(365.0 | units.day)
         hermite.particles.copy_values_of_all_attributes_to(stars)
-        
+
         position_at_start = earth.position.value_in(units.AU)[0]
         position_after_full_rotation = earth.position.value_in(units.AU)[0]
         self.assertAlmostRelativeEqual(position_at_start, position_after_full_rotation, 6)
-        
+
         hermite.evolve_model(365.0 - (365.0 / 2) | units.day)
-        
+
         hermite.particles.copy_values_of_all_attributes_to(stars)
         position_after_half_a_rotation_backward = earth.position.value_in(units.AU)[0]
         self.assertAlmostRelativeEqual(-position_at_start, position_after_half_a_rotation_backward, 4)
-                
+
         hermite.evolve_model(365.0 | units.day)
-        
+
         position_at_start = earth.position.value_in(units.AU)[0]
         position_after_full_rotation = earth.position.value_in(units.AU)[0]
         self.assertAlmostRelativeEqual(position_at_start, position_after_full_rotation, 6)
-        
+
         hermite.cleanup_code()
-        
+
         hermite.stop()
-        
+
     def test21(self):
         import pickle
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 149.5e6 | units.km)
-    
+
         hermite = Hermite(convert_nbody)
         encoded_interface = pickle.dumps(hermite,0)
         decoded_interface = pickle.loads(encoded_interface)
-        
-        
+
+
     def test22(self):
         hermite = Hermite()
         hermite.parameters.epsilon_squared = 0.0 | nbody_system.length**2
-        
+
         particles = datamodel.Particles(2)
         particles.position = ([0,0,0], [1,0,0] )| nbody_system.length
         particles.velocity = ([-2,0,0], [2,0,0] )| nbody_system.speed
         particles.radius = 0| nbody_system.length
         particles.mass = 0.1| nbody_system.mass
-                
+
         hermite.particles.add_particles(particles)
         hermite.stopping_conditions.out_of_box_detection.enable()
         hermite.parameters.stopping_conditions_out_of_box_size = 2 | nbody_system.length
@@ -830,18 +756,18 @@ class TestHermite(TestWithMPI):
         self.assertEqual(len(hermite.stopping_conditions.out_of_box_detection.particles(0)), 1)
         self.assertEqual(hermite.stopping_conditions.out_of_box_detection.particles(0)[0].key, particles[1].key)
         hermite.stop()
-        
+
 
     def test23(self):
         hermite = Hermite()
         hermite.parameters.epsilon_squared = 0.0 | nbody_system.length**2
-        
+
         particles = datamodel.Particles(1)
         particles.position = ([0,0,0] )| nbody_system.length
         particles.velocity = ([1,0,0] )| nbody_system.speed
         particles.radius = 0| nbody_system.length
         particles.mass = 0.1| nbody_system.mass
-                
+
         hermite.particles.add_particles(particles)
         hermite.evolve_model(1 | nbody_system.time)
         print(hermite.particles.x)
@@ -852,13 +778,13 @@ class TestHermite(TestWithMPI):
         self.assertAlmostRelativeEquals(hermite.model_time, 1.5 | nbody_system.time)
         self.assertAlmostRelativeEquals(hermite.particles[0].x, 1.5 | nbody_system.length)
         hermite.stop()
-        
+
 
     def test24(self):
-        hermite = Hermite(reuse_worker = True)
+        hermite = Hermite(reuse_worker=True)
         channel1 = hermite.legacy_interface.channel
         hermite.stop()
-        hermite = Hermite(reuse_worker = True)
+        hermite = Hermite(reuse_worker=True)
         channel2 = hermite.legacy_interface.channel
         hermite.stop()
         self.assertEqual(id(channel1), id(channel2))
@@ -866,7 +792,7 @@ class TestHermite(TestWithMPI):
     def test25(self):
         hermite = Hermite()
         hermite.parameters.epsilon_squared = 0.0 | nbody_system.length**2
-        
+
         particles = datamodel.Particles(10)
         particles.position = ([0,0,0] )| nbody_system.length
         particles.velocity = ([1,0,0] )| nbody_system.speed
@@ -874,7 +800,7 @@ class TestHermite(TestWithMPI):
         particles.mass = 0.1| nbody_system.mass
         particles.x = numpy.linspace(1, 10, 10) | nbody_system.length 
         particles.vx = numpy.linspace(1, 5, 10) | nbody_system.speed 
-                
+
         hermite.particles.add_particles(particles)
 
         request = hermite.particles.get_values_in_store_async(None, ["x"])
@@ -890,35 +816,35 @@ class TestHermite(TestWithMPI):
         channel = hermite.particles.new_channel_to(p)
         p.x = 0 | nbody_system.length
         p.vx = 0 | nbody_system.speed
-        request = channel.copy_attributes_async(("x","vx",), async_get = True)
+        request = channel.copy_attributes_async(("x","vx",), async_get=True)
         request.wait()
         self.assertEqual(p.x, particles.x)
         self.assertEqual(p.vx, particles.vx)
         p.x = 0 | nbody_system.length
         p.vx = 0 | nbody_system.speed
         channel = p.new_channel_to(hermite.particles)
-        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get = False, async_set = True)
+        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get=False, async_set=True)
         request.wait()
         self.assertEqual(p.x, hermite.particles.x)
         self.assertEqual(p.vx, hermite.particles.vx)
         channel = p.new_channel_to(particles)
-        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get = False, async_set = True)
+        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get=False, async_set=True)
         request.wait()
         self.assertEqual(p.x, particles.x)
         self.assertEqual(p.vx, particles.vx)
-        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get = True, async_set = False)
+        request = channel.copy_attributes_async(("x", "y", "z","vx","vy","vz"), async_get=True, async_set=False)
         request.wait()
         self.assertEqual(p.x, particles.x)
         self.assertEqual(p.vx, particles.vx)
 
-        
 
 
 
 
 
 
-        
+
+
 
 
 
